@@ -1,7 +1,13 @@
 import json
 from functools import partial
 
-from graphql import GraphQLError, ResolveInfo, Source, execute, parse
+from graphql import (
+    GraphQLError,
+    GraphQLResolveInfo as ResolveInfo,
+    Source,
+    execute,
+    parse,
+)
 
 from ..context import Context
 from ..dynamic import Dynamic
@@ -28,7 +34,7 @@ def test_query():
 
 
 def test_query_source():
-    class Root(object):
+    class Root:
         _hello = "World"
 
         def hello(self):
@@ -45,10 +51,10 @@ def test_query_source():
 
 
 def test_query_union():
-    class one_object(object):
+    class one_object:
         pass
 
-    class two_object(object):
+    class two_object:
         pass
 
     class One(ObjectType):
@@ -83,10 +89,10 @@ def test_query_union():
 
 
 def test_query_interface():
-    class one_object(object):
+    class one_object:
         pass
 
-    class two_object(object):
+    class two_object:
         pass
 
     class MyInterface(Interface):
@@ -175,7 +181,7 @@ def test_query_wrong_default_value():
     assert len(executed.errors) == 1
     assert (
         executed.errors[0].message
-        == GraphQLError('Expected value of type "MyType" but got: str.').message
+        == GraphQLError("Expected value of type 'MyType' but got: 'hello'.").message
     )
     assert executed.data == {"hello": None}
 
@@ -279,8 +285,7 @@ def test_query_middlewares():
             return "other"
 
     def reversed_middleware(next, *args, **kwargs):
-        p = next(*args, **kwargs)
-        return p.then(lambda x: x[::-1])
+        return next(*args, **kwargs)[::-1]
 
     hello_schema = Schema(Query)
 
@@ -342,10 +347,11 @@ def test_big_list_query_compiled_query_benchmark(benchmark):
             return big_list
 
     hello_schema = Schema(Query)
+    graphql_schema = hello_schema.graphql_schema
     source = Source("{ allInts }")
     query_ast = parse(source)
 
-    big_list_query = partial(execute, hello_schema, query_ast)
+    big_list_query = partial(execute, graphql_schema, query_ast)
     result = benchmark(big_list_query)
     assert not result.errors
     assert result.data == {"allInts": list(big_list)}
@@ -399,7 +405,7 @@ def test_big_list_of_containers_multiple_fields_query_benchmark(benchmark):
 
 
 def test_big_list_of_containers_multiple_fields_custom_resolvers_query_benchmark(
-    benchmark
+    benchmark,
 ):
     class Container(ObjectType):
         x = Int()
@@ -448,15 +454,15 @@ def test_query_annotated_resolvers():
         info = String()
 
         def resolve_annotated(self, info, id):
-            return "{}-{}".format(self, id)
+            return f"{self}-{id}"
 
         def resolve_context(self, info):
             assert isinstance(info.context, Context)
-            return "{}-{}".format(self, info.context.key)
+            return f"{self}-{info.context.key}"
 
         def resolve_info(self, info):
             assert isinstance(info, ResolveInfo)
-            return "{}-{}".format(self, info.field_name)
+            return f"{self}-{info.field_name}"
 
     test_schema = Schema(Query)
 
@@ -464,7 +470,7 @@ def test_query_annotated_resolvers():
     assert not result.errors
     assert result.data == {"annotated": "base-self"}
 
-    result = test_schema.execute("{ context }", "base", context_value=context)
+    result = test_schema.execute("{ context }", "base", context=context)
     assert not result.errors
     assert result.data == {"context": "base-context"}
 
