@@ -1,9 +1,10 @@
+from typing import TYPE_CHECKING
+
 from .base import BaseOptions, BaseType
 from .unmountedtype import UnmountedType
 
-# For static type checking with Mypy
-MYPY = False
-if MYPY:
+# For static type checking with type checker
+if TYPE_CHECKING:
     from .objecttype import ObjectType  # NOQA
     from typing import Iterable, Type  # NOQA
 
@@ -50,12 +51,14 @@ class Union(UnmountedType, BaseType):
     """
 
     @classmethod
-    def __init_subclass_with_meta__(cls, types=None, **options):
+    def __init_subclass_with_meta__(cls, types=None, _meta=None, **options):
         assert (
             isinstance(types, (list, tuple)) and len(types) > 0
         ), f"Must provide types for Union {cls.__name__}."
 
-        _meta = UnionOptions(cls)
+        if not _meta:
+            _meta = UnionOptions(cls)
+
         _meta.types = types
         super(Union, cls).__init_subclass_with_meta__(_meta=_meta, **options)
 
